@@ -35,6 +35,13 @@ test_that("Invalid `alpha`.", {
   expect_error(elmt(fit, rhs = rhs, alpha = 1))
 })
 
+test_that("Invalid `control`.", {
+  fit <- el_lm(mpg ~ cyl + disp, data = mtcars)
+  rhs <- c(0, 0, 0)
+  lhs <- rbind(c(1, 33, 0), c(0, 1, -100))
+  expect_error(elmt(fit, rhs = rhs, lhs = lhs, control = list(maxit = 10)))
+})
+
 test_that("Incompatible `rhs` and `lhs`.", {
   fit <- el_lm(mpg ~ cyl + disp, data = mtcars)
   rhs <- c(0, 0, 0)
@@ -96,11 +103,20 @@ test_that("`el_glm()` (binomial - logit).", {
     matrix(c(1, 100, 0, 0), nrow = 1),
     matrix(c(0, 1, -1, 0), nrow = 1)
   )
-  elmt(fit, lhs = lhs)
+  out <- elmt(fit, lhs = lhs)
   expect_output(print(fit))
   expect_output(print(summary(fit)))
+  expect_output(print(summary(out)))
+  expect_output(show(summary(out)))
   expect_equal(sum(exp(logProb(fit))), 1)
   expect_equal(sum(exp(logProb(wfit))), 1)
+  lhs2 <- list(
+    matrix(c(1, 100, 0, 0, 0, 2, 1, 1), nrow = 2),
+    matrix(c(0, 1, -1, 0), nrow = 1)
+  )
+  out <- elmt(fit, lhs = lhs2)
+  expect_output(print(summary(out)))
+  expect_output(show(summary(out)))
 })
 
 test_that("`el_glm()` (binomial - probit).", {
